@@ -7,7 +7,7 @@ class VenueSchema(Schema):
     class Meta:
         unknown = EXCLUDE
         api_type = 'venues'
-        url = 'venues'
+        url = 'event_management/venues'
         model = Venue
 
     id = fields.Int(missing=None)
